@@ -5,7 +5,7 @@ def value_list_to_comma(ini_key, values):
     Returns a comma separated list for use as a value in a WireGuard config file
     """
 
-    if isinstance(values, (list, set)):
+    if isinstance(values, (list, set, tuple,)):
         # Need to force to string, because the values are probably not simple strings
         values = ','.join(str(val) for val in values)
 
@@ -17,7 +17,7 @@ def value_list_to_multiple(ini_key, values):
     Returns multiple config lines for a given list of values
     """
 
-    if not isinstance(values, (list, set)):
+    if not isinstance(values, (list, set, tuple,)):
         values = [values]
 
     data = []
